==> 0.7.4:frontend.zip: appflowy/appflowy_flutter/lib/plugins/document/presentation/editor_plugins/plugins.dart <==
export 'actions/block_action_list.dart';
export 'actions/option/option_actions.dart';
export 'align_toolbar_item/align_toolbar_item.dart';
export 'base/backtick_character_command.dart';
export 'base/cover_title_command.dart';
export 'base/toolbar_extension.dart';
export 'bulleted_list/bulleted_list_icon.dart';
export 'callout/callout_block_component.dart';
export 'code_block/code_block_language_selector.dart';
export 'code_block/code_block_menu_item.dart';
export 'context_menu/custom_context_menu.dart';
export 'copy_and_paste/custom_copy_command.dart';
export 'copy_and_paste/custom_cut_command.dart';
export 'copy_and_paste/custom_paste_command.dart';
export 'database/database_view_block_component.dart';
export 'database/inline_database_menu_item.dart';
export 'database/referenced_database_menu_item.dart';
export 'error/error_block_component_builder.dart';
export 'extensions/flowy_tint_extension.dart';
export 'file/file_block.dart';
export 'find_and_replace/find_and_replace_menu.dart';
export 'font/customize_font_toolbar_item.dart';
export 'header/cover_editor_bloc.dart';
export 'header/custom_cover_picker.dart';
export 'header/document_cover_widget.dart';
export 'heading/heading_toolbar_item.dart';
export 'image/custom_image_block_component/image_menu.dart';
export 'image/image_selection_menu.dart';
export 'image/mobile_image_toolbar_item.dart';
export 'image/multi_image_block_component/multi_image_menu.dart';
export 'inline_math_equation/inline_math_equation.dart';
export 'inline_math_equation/inline_math_equation_toolbar_item.dart';
export 'keyboard_interceptor/keyboard_interceptor.dart';
export 'link_preview/custom_link_preview.dart';
export 'link_preview/link_preview_cache.dart';
export 'link_preview/link_preview_menu.dart';
export 'math_equation/math_equation_block_component.dart';
export 'math_equation/mobile_math_equation_toolbar_item.dart';
export 'mobile_floating_toolbar/custom_mobile_floating_toolbar.dart';
export 'mobile_toolbar_v3/aa_toolbar_item.dart';
export 'mobile_toolbar_v3/add_block_toolbar_item.dart';
export 'mobile_toolbar_v3/appflowy_mobile_toolbar.dart';
export 'mobile_toolbar_v3/appflowy_mobile_toolbar_item.dart';
export 'mobile_toolbar_v3/biusc_toolbar_item.dart';
export 'mobile_toolbar_v3/indent_outdent_toolbar_item.dart';
export 'mobile_toolbar_v3/list_toolbar_item.dart';
export 'mobile_toolbar_v3/more_toolbar_item.dart';
export 'mobile_toolbar_v3/toolbar_item_builder.dart';
export 'mobile_toolbar_v3/undo_redo_toolbar_item.dart';
export 'mobile_toolbar_v3/util.dart';
export 'numbered_list/numbered_list_icon.dart';
export 'openai/widgets/auto_completion_node_widget.dart';
export 'openai/widgets/smart_edit_node_widget.dart';
export 'openai/widgets/smart_edit_toolbar_item.dart';
export 'outline/outline_block_component.dart';
export 'parsers/markdown_parsers.dart';
export 'quote/quote_block_shortcuts.dart';
export 'shortcuts/character_shortcuts.dart';
export 'shortcuts/command_shortcuts.dart';
export 'slash_menu/slash_menu_items.dart';
export 'table/table_menu.dart';
export 'table/table_option_action.dart';
export 'todo_list/todo_list_icon.dart';
export 'toggle/toggle_block_component.dart';
export 'toggle/toggle_block_shortcuts.dart';
export 'sub_page/sub_page_block_component.dart';
export 'mention/mention_block.dart';
export 'image/custom_image_block_component/custom_image_block_component.dart';
export 'image/multi_image_block_component/multi_image_block_component.dart';

==> 0.8.6:frontend.zip: appflowy/appflowy_flutter/lib/plugins/document/presentation/editor_plugins/plugins.dart <==
export 'actions/block_action_list.dart';
export 'actions/option/option_actions.dart';
export 'ai/ai_writer_block_component.dart';
export 'ai/ai_writer_toolbar_item.dart';
export 'align_toolbar_item/align_toolbar_item.dart';
export 'base/backtick_character_command.dart';
export 'base/cover_title_command.dart';
export 'base/toolbar_extension.dart';
export 'bulleted_list/bulleted_list_icon.dart';
export 'callout/callout_block_component.dart';
export 'code_block/code_block_language_selector.dart';
export 'code_block/code_block_menu_item.dart';
export 'columns/simple_column_block_component.dart';
export 'columns/simple_column_block_width_resizer.dart';
export 'columns/simple_column_node_extension.dart';
export 'columns/simple_columns_block_component.dart';
export 'context_menu/custom_context_menu.dart';
export 'copy_and_paste/custom_copy_command.dart';
export 'copy_and_paste/custom_cut_command.dart';
export 'copy_and_paste/custom_paste_command.dart';
export 'database/database_view_block_component.dart';
export 'database/inline_database_menu_item.dart';
export 'database/referenced_database_menu_item.dart';
export 'error/error_block_component_builder.dart';
export 'extensions/flowy_tint_extension.dart';
export 'file/file_block.dart';
export 'find_and_replace/find_and_replace_menu.dart';
export 'font/customize_font_toolbar_item.dart';
export 'header/cover_editor_bloc.dart';
export 'header/custom_cover_picker.dart';
export 'header/document_cover_widget.dart';
export 'heading/heading_toolbar_item.dart';
export 'image/custom_image_block_component/custom_image_block_component.dart';
export 'image/custom_image_block_component/image_menu.dart';
export 'image/image_selection_menu.dart';
export 'image/mobile_image_toolbar_item.dart';
export 'image/multi_image_block_component/multi_image_block_component.dart';
export 'image/multi_image_block_component/multi_image_menu.dart';
export 'inline_math_equation/inline_math_equation.dart';
export 'inline_math_equation/inline_math_equation_toolbar_item.dart';
export 'keyboard_interceptor/keyboard_interceptor.dart';
export 'link_preview/custom_link_preview.dart';
export 'link_preview/link_preview_cache.dart';
export 'link_preview/link_preview_menu.dart';
export 'math_equation/math_equation_block_component.dart';
export 'math_equation/mobile_math_equation_toolbar_item.dart';
export 'mention/mention_block.dart';
export 'mobile_floating_toolbar/custom_mobile_floating_toolbar.dart';
export 'mobile_toolbar_v3/aa_toolbar_item.dart';
export 'mobile_toolbar_v3/add_attachment_item.dart';
export 'mobile_toolbar_v3/add_block_toolbar_item.dart';
export 'mobile_toolbar_v3/appflowy_mobile_toolbar.dart';
export 'mobile_toolbar_v3/appflowy_mobile_toolbar_item.dart';
export 'mobile_toolbar_v3/basic_toolbar_item.dart';
export 'mobile_toolbar_v3/indent_outdent_toolbar_item.dart';
export 'mobile_toolbar_v3/list_toolbar_item.dart';
export 'mobile_toolbar_v3/more_toolbar_item.dart';
export 'mobile_toolbar_v3/toolbar_item_builder.dart';
export 'mobile_toolbar_v3/undo_redo_toolbar_item.dart';
export 'mobile_toolbar_v3/util.dart';
export 'numbered_list/numbered_list_icon.dart';
export 'outline/outline_block_component.dart';
export 'parsers/document_markdown_parsers.dart';
export 'parsers/markdown_parsers.dart';
export 'parsers/markdown_simple_table_parser.dart';
export 'quote/quote_block_shortcuts.dart';
export 'shortcuts/character_shortcuts.dart';
export 'shortcuts/command_shortcuts.dart';
export 'simple_table/simple_table.dart';
export 'slash_menu/slash_command.dart';
export 'slash_menu/slash_menu_items_builder.dart';
export 'sub_page/sub_page_block_component.dart';
export 'table/table_menu.dart';
export 'table/table_option_action.dart';
export 'todo_list/todo_list_icon.dart';
export 'toggle/toggle_block_component.dart';
export 'toggle/toggle_block_shortcuts.dart';
export 'video/video_block_component.dart';
